@@ -1,8 +1,11 @@
+#ifndef _FR_MISSING_H
+#define _FR_MISSING_H
+
 /*
  * missing.h	Replacements for functions that are or can be
  *		missing on some platforms.
  *
- * Version:	$Id: missing.h,v 1.17 2001/03/08 21:31:21 aland Exp $
+ * Version:	$Id$
  *
  */
 #ifndef HAVE_STRNCASECMP
@@ -17,6 +20,14 @@ extern int strcasecmp(char *s1, char *s2);
 extern char *strsep(char **stringp, const char *delim);
 #endif
 
+#ifndef HAVE_LOCALTIME_R
+struct tm *localtime_r(const time_t *l_clock, struct tm *result);
+#endif
+
+#ifndef HAVE_CTIME_R
+char *ctime_r(const time_t *l_clock, char *l_buf);
+#endif
+
 #ifdef NEED_DECLARATION_CRYPT
 char *crypt(char *key, char *salt);
 #endif
@@ -69,3 +80,5 @@ void endusershell(void);
 #ifndef INADDR_NONE
 #define INADDR_NONE     ((uint32_t) 0xffffffff)
 #endif
+
+#endif /* _FR_MISSING_H */
