@@ -1,7 +1,7 @@
 /*
  * radius.h	Constants of the radius protocol.
  *
- * Version:	$Id: radius.h,v 1.66.4.2 2006/03/07 18:10:08 aland Exp $
+ * Version:	$Id$
  *
  */
 
@@ -199,6 +199,8 @@
 #define PW_SSHA_PASSWORD		1094
 #define PW_MD5_PASSWORD			1095
 #define PW_SMD5_PASSWORD		1096
+#define PW_CLEARTEXT_PASSWORD		1100
+#define PW_PASSWORD_WITH_HEADER		1101
 
 
 /*
