@@ -1,7 +1,7 @@
 /*
  * sysutmp.h	Compatibility stuff for the different UTMP systems.
  *
- * Version:	$Id: sysutmp.h,v 1.9 2002/09/30 18:10:13 aland Exp $
+ * Version:	$Id$
  */
 
 #ifndef SYSUTMP_H_INCLUDED
@@ -40,7 +40,7 @@
 #  define UT_HOSTSIZE	64
 #endif
 
-#if defined(__FreeBSD__) || defined(__NetBSD__) || defined(bsdi) || defined(__OpenBSD__)
+#if defined(__FreeBSD__) || defined(__NetBSD__) || defined(bsdi) || defined(__OpenBSD__) || defined(__APPLE__)
 #  ifndef UTMP_FILE
 #    define UTMP_FILE "/var/run/utmp"
 #  endif
