@@ -1,7 +1,7 @@
 /*
  * dict.c	Routines to read the dictionary file.
  *
- * Version:	$Id: dict.c,v 1.50.2.4.2.13 2006/11/26 19:50:14 aland Exp $
+ * Version:	$Id$
  *
  *   This library is free software; you can redistribute it and/or
  *   modify it under the terms of the GNU Lesser General Public
@@ -20,7 +20,7 @@
  * Copyright 2000  The FreeRADIUS server project
  */
 
-static const char rcsid[] = "$Id: dict.c,v 1.50.2.4.2.13 2006/11/26 19:50:14 aland Exp $";
+static const char rcsid[] = "$Id$";
 
 #include	"autoconf.h"
 
@@ -486,6 +486,7 @@ int dict_addattr(const char *name, int vendor, int type, int value,
 		if (a && (strcasecmp(a->name, attr->name) == 0)) {
 			if (a->attr != attr->attr) {
 				librad_log("dict_addattr: Duplicate attribute name %s", name);
+				free(attr);
 				return -1;
 			}
 
@@ -496,6 +497,14 @@ int dict_addattr(const char *name, int vendor, int type, int value,
 			 *	over-ride the old one.
 			 */
 		}
+
+		lrad_hash_table_delete(attributes_byvalue, a);
+
+		if (!lrad_hash_table_replace(attributes_byname, attr)) {
+			librad_log("dict_addattr: Internal error storing attribute %s", name);
+			free(attr);
+			return -1;
+		}
 	}
 
 	/*
@@ -553,6 +562,7 @@ int dict_addvalue(const char *namestr, const char *attrstr, int value)
 		 */
 		if ((dattr->type != PW_TYPE_INTEGER) &&
 		    (dattr->type != PW_TYPE_OCTETS)) {
+			free(dval);
 			librad_log("dict_addvalue: VALUEs can only be defined for'integer' types");
 			return -1;
 		}
@@ -562,6 +572,7 @@ int dict_addvalue(const char *namestr, const char *attrstr, int value)
 		
 		fixup = (value_fixup_t *) malloc(sizeof(*fixup));
 		if (!fixup) {
+			free(dval);
 			librad_log("dict_addvalue: out of memory");
 			return -1;
 		}
@@ -598,6 +609,7 @@ int dict_addvalue(const char *namestr, const char *attrstr, int value)
 			}
 		}
 
+		free(dval);
 		librad_log("dict_addvalue: Duplicate value name %s for attribute %s", namestr, attrstr);
 		return -1;
 	}
@@ -935,8 +947,13 @@ static int my_dict_init(const char *dir, const char *fn,
 	char	*argv[MAX_ARGV];
 	int	argc;
 
-	if (strlen(fn) >= sizeof(dirtmp) / 2 ||
-	    strlen(dir) >= sizeof(dirtmp) / 2) {
+	if (!dir) {
+		librad_log("dict_init: No directory specified");
+		return -1;
+	}
+
+	if ((strlen(fn) >= sizeof(dirtmp) / 2) ||
+	    (strlen(dir) >= sizeof(dirtmp) / 2)) {
 		librad_log("dict_init: filename name too long");
 		return -1;
 	}
@@ -949,7 +966,8 @@ static int my_dict_init(const char *dir, const char *fn,
 		strcpy(dirtmp, fn);
 		dirtmp[p - fn] = 0;
 		dir = dirtmp;
-	} else if (dir && dir[0] && strcmp(dir, ".") != 0) {
+
+	} else if (dir[0] && strcmp(dir, ".") != 0) {
 		snprintf(dirtmp, sizeof(dirtmp), "%s/%s", dir, fn);
 		fn = dirtmp;
 	}
@@ -972,6 +990,18 @@ static int my_dict_init(const char *dir, const char *fn,
 			   fn);
 		return -1;	  
 	}
+
+	/*
+	 *	Globally writable dictionaries means that users can control
+	 *	the server configuration with little difficulty.
+	 */
+	if ((statbuf.st_mode & S_IWOTH) != 0) {
+		fclose(fp);
+		librad_log("dict_init: Dictionary \"%s\" is globally writable.  Refusing to start due to insecure configuration.",
+			   fn);
+		return -1;
+	}
+
 	dict_stat_add(fn, &statbuf);
 
 	/*
@@ -1142,6 +1172,8 @@ static int null_callback(void *ctx, void *data)
  */
 int dict_init(const char *dir, const char *fn)
 {
+	if (!dir) return -1;
+
 	/*
 	 *	Check if we need to change anything.  If not, don't do
 	 *	anything.
