@@ -1,7 +1,7 @@
 /*
  * misc.c	Various miscellaneous functions.
  *
- * Version:	$Id: misc.c,v 1.41.2.3.2.2 2006/03/15 15:37:56 nbk Exp $
+ * Version:	$Id$
  *
  *   This library is free software; you can redistribute it and/or
  *   modify it under the terms of the GNU Lesser General Public
@@ -21,7 +21,7 @@
  */
 
 static const char rcsid[] =
-"$Id: misc.c,v 1.41.2.3.2.2 2006/03/15 15:37:56 nbk Exp $";
+"$Id$";
 
 #include	"autoconf.h"
 
@@ -469,3 +469,33 @@ void lrad_bin2hex(const uint8_t *bin, char *hex, int len)
 	return;
 }
 
+/*
+ *	So we don't have ifdef's in the rest of the code
+ */
+#ifndef HAVE_CLOSEFROM
+int closefrom(int fd)
+{
+	int i;
+	int maxfd = 256;
+
+#ifdef _SC_OPEN_MAX
+	maxfd = sysconf(_SC_OPEN_MAX);
+	if (maxfd < 0) {
+	  maxfd = 256;
+	}
+#endif
+
+	if (fd > maxfd) return 0;
+
+	/*
+	 *	FIXME: return EINTR?
+	 *
+	 *	Use F_CLOSEM?
+	 */
+	for (i = fd; i < maxfd; i++) {
+		close(i);
+	}
+
+	return 0;
+}
+#endif
