@@ -1,7 +1,7 @@
 /*
  * radius.c	Functions to send/receive radius packets.
  *
- * Version:	$Id: radius.c,v 1.125.2.5.2.8 2006/08/16 20:03:35 aland Exp $
+ * Version:	$Id$
  *
  *   This library is free software; you can redistribute it and/or
  *   modify it under the terms of the GNU Lesser General Public
@@ -20,7 +20,7 @@
  * Copyright 2000-2003  The FreeRADIUS server project
  */
 
-static const char rcsid[] = "$Id: radius.c,v 1.125.2.5.2.8 2006/08/16 20:03:35 aland Exp $";
+static const char rcsid[] = "$Id$";
 
 #include	"autoconf.h"
 #include	"md5.h"
@@ -657,18 +657,6 @@ int rad_encode(RADIUS_PACKET *packet, const RADIUS_PACKET *original,
 			continue;
 		}
 		
-		/*
-		 *	Check that the packet is no more than 4k in
-		 *	size, AFTER over-flowing the 4k boundary.
-		 *	Note that the 'data' buffer, above, is one
-		 *	attribute longer than necessary, in order to
-		 *	permit this overflow.
-		 */
-		if (total_length > MAX_PACKET_LEN) {
-			librad_log("ERROR: Too many attributes for packet, result is larger than RFC maximum of 4k");
-			return -1;
-		}
-		
 		/*
 		 *	Set the Message-Authenticator to the correct
 		 *	length and initial value.
@@ -688,6 +676,19 @@ int rad_encode(RADIUS_PACKET *packet, const RADIUS_PACKET *original,
 
 		len = rad_vp2attr(packet, original, secret, reply, ptr);
 		if (len < 0) return -1;
+
+		/*
+		 *	Check that the packet is no more than 4k in
+		 *	size, AFTER writing the attribute past the 4k
+		 *	boundary, but BEFORE deciding to increase the
+		 *	size of the packet. Note that the 'data'
+		 *	buffer, above, is one attribute longer than
+		 *	necessary, in order to permit this overflow.
+		 */
+		if ((total_length + len) > MAX_PACKET_LEN) {
+			break;
+		}
+
 		ptr += len;
 		total_length += len;
 	} /* done looping over all attributes */
@@ -1023,7 +1024,8 @@ RADIUS_PACKET *rad_recv(int fd)
 	int			count;
 	radius_packet_t		*hdr;
 	char			host_ipaddr[16];
-	int			seen_eap;
+	int			require_ma = 0;
+	int			seen_ma = 0;
 	uint8_t			data[MAX_PACKET_LEN];
 	int			num_attributes;
 
@@ -1135,6 +1137,12 @@ RADIUS_PACKET *rad_recv(int fd)
 		return NULL;
 	}
 
+	/*
+	 *	Message-Authenticator is required in Status-Server
+	 *	packets, otherwise they can be trivially forged.
+	 */
+	if (hdr->code == PW_STATUS_SERVER) require_ma = 1;
+
 	/*
 	 *	Repeat the length checks.  This time, instead of
 	 *	looking at the data we received, look at the value
@@ -1214,7 +1222,6 @@ RADIUS_PACKET *rad_recv(int fd)
 	 */
 	attr = hdr->data;
 	count = totallen - AUTH_HDR_LEN;
-	seen_eap = 0;
 	num_attributes = 0;
 
 	while (count > 0) {
@@ -1247,8 +1254,13 @@ RADIUS_PACKET *rad_recv(int fd)
 		default:	/* don't do anything by default */
 			break;
 
+
+			/*
+			 *	If there's an EAP-Message, we require
+			 *	a Message-Authenticator.
+			 */
 		case PW_EAP_MESSAGE:
-			seen_eap |= PW_EAP_MESSAGE;
+			require_ma = 1;
 			break;
 
 		case PW_MESSAGE_AUTHENTICATOR:
@@ -1259,7 +1271,7 @@ RADIUS_PACKET *rad_recv(int fd)
 				free(packet);
 				return NULL;
 			}
-			seen_eap |= PW_MESSAGE_AUTHENTICATOR;
+			seen_ma = 1;
 			break;
 		}
 
@@ -1307,11 +1319,12 @@ RADIUS_PACKET *rad_recv(int fd)
 	 *	a Message-Authenticator attribute.
 	 *
 	 *	A Message-Authenticator all by itself is OK, though.
+	 *
+	 *	Similarly, Status-Server packets MUST contain
+	 *	Message-Authenticator attributes.
 	 */
-	if (seen_eap &&
-	    (seen_eap != PW_MESSAGE_AUTHENTICATOR) &&
-	    (seen_eap != (PW_EAP_MESSAGE | PW_MESSAGE_AUTHENTICATOR))) {
-		librad_log("WARNING: Insecure packet from host %s:  Received EAP-Message with no Message-Authenticator.",
+	if (require_ma && ! seen_ma) {
+		librad_log("WARNING: Insecure packet from host %s:  Packet does not contain required Message-Authenticator attribute",
 			   ip_ntoa(host_ipaddr, packet->src_ipaddr));
 		free(packet);
 		return NULL;
@@ -1951,6 +1964,11 @@ int rad_decode(RADIUS_PACKET *packet, RADIUS_PACKET *original,
 		 *	over-ride this one.
 		 */
 	create_pair:
+		/*
+		 *	Ignore VSAs that have no data.
+		 */
+		if (attrlen == 0) goto next;
+
 		pair = rad_attr2vp(packet, original, secret,
 				 attribute, attrlen, ptr);
 		if (!pair) {
@@ -1963,6 +1981,7 @@ int rad_decode(RADIUS_PACKET *packet, RADIUS_PACKET *original,
 		*tail = pair;
 		tail = &pair->next;
 
+	next:
 		ptr += attrlen;
 		packet_length -= attrlen;
 	}
