@@ -1,7 +1,7 @@
 /*
  * mainconf.c	Handle the server's configuration.
  *
- * Version:	$Id: mainconfig.c,v 1.36.2.6.2.2 2006/04/18 17:26:26 aland Exp $
+ * Version:	$Id$
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -381,13 +381,13 @@ static int generate_realms(const char *filename)
 		 */
 		if ((authhost = cf_section_value_find(cs, "authhost")) == NULL) {
 			c->ipaddr = htonl(INADDR_NONE);
-			c->auth_port = auth_port;
+			c->auth_port = 0;
 		} else {
 			if ((s = strchr(authhost, ':')) != NULL) {
 				*s++ = 0;
 				c->auth_port = atoi(s);
 			} else {
-				c->auth_port = auth_port;
+				c->auth_port = PW_AUTH_UDP_PORT;
 			}
 			if (strcmp(authhost, "LOCAL") == 0) {
 				/*
@@ -395,10 +395,11 @@ static int generate_realms(const char *filename)
 				 *	secret, or port.
 				 */
 				c->ipaddr = htonl(INADDR_NONE);
-				c->auth_port = auth_port;
+				c->auth_port = 0;
 			} else {
 				c->ipaddr = ip_getaddr(authhost);
 				if (c->ipaddr == htonl(INADDR_NONE)) {
+					free(c);
 					radlog(L_ERR, "%s[%d]: Host %s not found",
 					       filename, cf_section_lineno(cs),
 					       authhost);
@@ -410,6 +411,7 @@ static int generate_realms(const char *filename)
 			 * Double check length, just to be sure!
 			 */
 			if (strlen(authhost) >= sizeof(c->server)) {
+				free(c);
 				radlog(L_ERR, "%s[%d]: Server name of length %d is greater than allowed: %d",
 				       filename, cf_section_lineno(cs),
 				       (int) strlen(authhost),
@@ -429,7 +431,7 @@ static int generate_realms(const char *filename)
 				*s++ = 0;
 				c->acct_port = atoi(s);
 			} else {
-				c->acct_port = auth_port + 1;
+				c->acct_port = PW_ACCT_UDP_PORT;
 			}
 			if (strcmp(accthost, "LOCAL") == 0) {
 				/*
@@ -441,6 +443,7 @@ static int generate_realms(const char *filename)
 			} else {
 				c->acct_ipaddr = ip_getaddr(accthost);
 				if (c->acct_ipaddr == htonl(INADDR_NONE)) {
+					free(c);
 					radlog(L_ERR, "%s[%d]: Host %s not found",
 					       filename, cf_section_lineno(cs),
 					       accthost);
@@ -449,6 +452,7 @@ static int generate_realms(const char *filename)
 			}
 
 			if (strlen(accthost) >= sizeof(c->acct_server)) {
+				free(c);
 				radlog(L_ERR, "%s[%d]: Server name of length %d is greater than allowed: %d",
 				       filename, cf_section_lineno(cs),
 				       (int) strlen(accthost),
@@ -458,6 +462,7 @@ static int generate_realms(const char *filename)
 		}
 
 		if (strlen(name2) >= sizeof(c->realm)) {
+			free(c);
 			radlog(L_ERR, "%s[%d]: Realm name of length %d is greater than allowed %d",
 			       filename, cf_section_lineno(cs),
 			       (int) strlen(name2),
@@ -477,12 +482,14 @@ static int generate_realms(const char *filename)
 		if ((c->ipaddr != htonl(INADDR_NONE)) ||
 		    (c->acct_ipaddr != htonl(INADDR_NONE))) {
 			if ((s = cf_section_value_find(cs, "secret")) == NULL ) {
+				free(c);
 				radlog(L_ERR, "%s[%d]: No shared secret supplied for realm: %s",
 				       filename, cf_section_lineno(cs), name2);
 				return -1;
 			}
 
 			if (strlen(s) >= sizeof(c->secret)) {
+				free(c);
 				radlog(L_ERR, "%s[%d]: Secret of length %u is greater than the allowed maximum of %u.",
 				       filename, cf_section_lineno(cs),
 				       strlen(s), sizeof(c->secret) - 1);
@@ -512,6 +519,7 @@ static int generate_realms(const char *filename)
 
 			c->ldflag = lrad_str2int(ldflags, t, -1);
 			if (c->ldflag == -1) {
+				free(c);
 				radlog(L_ERR, "%s[%d]: Unknown value \"%s\" for ldflag",
 				       filename, cf_section_lineno(cs),
 				       t);
@@ -692,6 +700,7 @@ static RADCLIENT *generate_clients(const char *filename, CONF_SECTION *section)
 				radlog(L_ERR, "%s[%d]: Invalid value '%s' for IP network mask.",
 						filename, cf_section_lineno(cs), netmask + 1);
 				clients_free(list);
+				free(c);
 				return NULL;
 			}
 
@@ -710,6 +719,7 @@ static RADCLIENT *generate_clients(const char *filename, CONF_SECTION *section)
 			radlog(L_CONS|L_ERR, "%s[%d]: Failed to look up hostname %s",
 					filename, cf_section_lineno(cs), hostnm);
 			clients_free(list);
+			free(c);
 			return NULL;
 		}
 
@@ -902,7 +912,10 @@ int proxy_new_listener(void)
 	/*
 	 *	Proxying was not previously defined: die.
 	 */
-	if (last_proxy_port == 0) return -1;
+	if (last_proxy_port == 0) {
+		free(this);
+		return -1;
+	}
 
 	/*
 	 *	Keep going until we find an unused port.
@@ -929,6 +942,7 @@ int proxy_new_listener(void)
 		}
 	}
 
+	free(this);
 	return -1;
 }
 
@@ -1224,6 +1238,26 @@ CONF_SECTION *read_radius_conf_file(void)
 {
 	char buffer[256];
 	CONF_SECTION *cs;
+	struct stat statbuf;
+
+	if (stat(radius_dir, &statbuf) < 0) {
+		radlog(L_ERR|L_CONS, "Errors reading %s: %s",
+		       radius_dir, strerror(errno));
+		return NULL;
+	}
+
+	if ((statbuf.st_mode & S_IWOTH) != 0) {
+		radlog(L_ERR|L_CONS, "Configuration directory %s is globally writable.  Refusing to start due to insecure configuration.",
+		       radius_dir);
+	  return NULL;
+	}
+
+
+	if (0 && (statbuf.st_mode & S_IROTH) != 0) {
+		radlog(L_ERR|L_CONS, "Configuration directory %s is globally readable.  Refusing to start due to insecure configuration.",
+		       radius_dir);
+		return NULL;
+	}
 
 	/* Lets go look for the new configuration files */
 	snprintf(buffer, sizeof(buffer), "%.200s/%.50s", radius_dir, RADIUS_CONFIG);
@@ -1476,6 +1510,14 @@ int free_mainconfig(void)
 	cf_section_free(&mainconfig.config);
 	realm_free(mainconfig.realms);
 	clients_free(mainconfig.clients);
+	read_naslist_file(NULL);
+
+	rl_free();
+	listen_free(mainconfig.listen);
+	paircompare_builtin_free();
+	xlat_free();
+	dict_free();
+	lt_dlexit();
 
 	return 0;
 }
