@@ -26,7 +26,7 @@
  *
  */
 char radrelay_rcsid[] =
-"$Id: radrelay.c,v 1.22.2.3.2.2 2006/05/16 18:26:08 aland Exp $";
+"$Id$";
 
 #include "autoconf.h"
 
@@ -389,8 +389,10 @@ int do_recv(struct relay_misc *r_args)
 	 *	Must be an accounting response.
 	 *	FIXME: check if this is the right server!
 	 */
-	if (rep->code != PW_ACCOUNTING_RESPONSE)
+	if (rep->code != PW_ACCOUNTING_RESPONSE) {
+		rad_free(&rep);
 		return -1;
+	}
 
 	/*
 	 *	Decode packet into radius attributes.
@@ -404,10 +406,12 @@ int do_recv(struct relay_misc *r_args)
 		if (r->state == STATE_FULL && r->req->id == rep->id) {
 			if (rad_verify(rep, r->req, r_args->secret) != 0) {
 				librad_perror("rad_verify");
+				rad_free(&rep);
 				return -1;
 			}
 			if (rad_decode(rep, r->req, r_args->secret) != 0) {
 				librad_perror("rad_decode");
+				rad_free(&rep);
 				return -1;
 			}
 			/*
