@@ -1,7 +1,7 @@
 /*
  * timestr.c	See if a string like 'Su2300-0700' matches (UUCP style).
  *
- * Version:	$Id: timestr.c,v 1.15 2002/06/21 19:57:27 cparker Exp $
+ * Version:	$Id$
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
  * Copyright 2000  Alan DeKok <aland@ox.org>
  */
 
-static const char rcsid[] = "$Id: timestr.c,v 1.15 2002/06/21 19:57:27 cparker Exp $";
+static const char rcsid[] = "$Id$";
 
 #include	"autoconf.h"
 #include	"libradius.h"
@@ -138,7 +138,7 @@ static int day_fill(char *bitmap, const char *tm)
 	for (hr = tm; *hr; hr++)
 		if (isdigit((int) *hr))
 			break;
-	if (hr == tm) 
+	if (hr == tm)
 		tm = "Al";
 
 	timestr_debug("dayfill: hr %s    tm %s\n", hr, tm);
@@ -207,7 +207,7 @@ int timestr_match(char *tmstr, time_t t)
 	char bitmap[WEEKMIN / 8];
 	int now, tot, i;
 	int byte, bit;
-#if do_timestr_debug
+#ifdef do_timestr_debug
 	int y;
 	char *s;
 	char null[8];
@@ -219,7 +219,7 @@ int timestr_match(char *tmstr, time_t t)
 	memset(bitmap, 0, sizeof(bitmap));
 	week_fill(bitmap, tmstr);
 
-#if do_timestr_debug
+#ifdef do_timestr_debug
 	memset(null, 0, 8);
 	for (i = 0; i < 7; i++) {
 		timestr_debug("%d: ", i);
@@ -249,7 +249,7 @@ int timestr_match(char *tmstr, time_t t)
 			break;
 	}
 
-	if (tot == 0) 
+	if (tot == 0)
 		return -1;
 
 	return (i == now) ? 0 : tot;
