@@ -1,7 +1,7 @@
 /*
  * tls.c
  *
- * Version:     $Id: tls.c,v 1.1.2.3 2006/04/27 18:53:23 aland Exp $
+ * Version:     $Id$
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -92,11 +92,15 @@ tls_session_t *eaptls_new_session(SSL_CTX *ssl_ctx, int client_cert)
 /*
  *	Print out some text describing the error.
  */
-static void int_ssl_check(SSL *s, int ret, const char *text)
+static int int_ssl_check(SSL *s, int ret, const char *text)
 {
 	int e;
+	unsigned long l;
 
-	radlog(L_ERR, "rlm_eap: SSL error %s", ERR_error_string(ERR_get_error(), NULL));
+	if ((l = ERR_get_error()) != 0) {
+		radlog(L_ERR, "rlm_eap: SSL error %s",
+		       ERR_error_string(l, NULL));
+	}
 	e = SSL_get_error(s, ret);
 
 	switch(e) {
@@ -117,7 +121,7 @@ static void int_ssl_check(SSL *s, int ret, const char *text)
 	case SSL_ERROR_WANT_WRITE:
 	case SSL_ERROR_WANT_X509_LOOKUP:
 	case SSL_ERROR_ZERO_RETURN:
-		return;
+		break;
 
 		/*
 		 *	These seem to be indications of a genuine
@@ -127,14 +131,12 @@ static void int_ssl_check(SSL *s, int ret, const char *text)
 	case SSL_ERROR_SYSCALL:
 		radlog(L_ERR, "rlm_eap_tls: %s failed in a system call (%d), TLS session fails.",
 		       text, ret);
-		SSL_set_app_data(s, (char *)1);
-		return;
+		return 0;
 
 	case SSL_ERROR_SSL:
 		radlog(L_ERR, "rlm_eap_tls: %s failed inside of TLS (%d), TLS session fails.",
 		       text, ret);
-		SSL_set_app_data(s, (char *)1);
-		return;
+		return 0;
 
 	default:
 		/*
@@ -144,8 +146,10 @@ static void int_ssl_check(SSL *s, int ret, const char *text)
 		 *	the code needs updating here.
 		 */
 		radlog(L_ERR, "rlm_eap_tls: FATAL SSL error ..... %d\n", e);
-		break;
+		return 0;
 	}
+
+	return 1;
 }
 
 /*
@@ -170,8 +174,8 @@ int tls_handshake_recv(tls_session_t *ssn)
 		       sizeof(ssn->clean_out.data));
 	if (err > 0) {
 		ssn->clean_out.used = err;
-	} else {
-		int_ssl_check(ssn->ssl, err, "SSL_read");
+	} else if (!int_ssl_check(ssn->ssl, err, "SSL_read")) {
+		return 0;
 	}
 
 	/* Some Extra STATE information for easy debugging */
