@@ -1,7 +1,7 @@
 /*
  * rlm_eap.c  contains handles that are called from modules.
  *
- * Version:     $Id: rlm_eap.c,v 1.26.2.1 2005/06/03 17:10:17 aland Exp $
+ * Version:     $Id$
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -26,7 +26,7 @@
 #include "rlm_eap.h"
 #include "modules.h"
 
-static const char rcsid[] = "$Id: rlm_eap.c,v 1.26.2.1 2005/06/03 17:10:17 aland Exp $";
+static const char rcsid[] = "$Id$";
 
 static const CONF_PARSER module_config[] = {
 	{ "default_eap_type", PW_TYPE_STRING_PTR,
@@ -41,12 +41,6 @@ static const CONF_PARSER module_config[] = {
  	{ NULL, -1, 0, NULL, NULL }           /* end the list */
 };
 
-static int eap_init(void)
-{
-	return 0;
-}
-
-
 /*
  * delete all the allocated space by eap module
  */
@@ -57,6 +51,8 @@ static int eap_detach(void *instance)
 
 	inst = (rlm_eap_t *)instance;
 
+	rbtree_free(inst->session_tree);
+	inst->session_tree = NULL;
 	eaplist_free(inst);
 
 	for (i = 0; i < PW_EAP_MAX_TYPES; i++) {
@@ -64,10 +60,7 @@ static int eap_detach(void *instance)
 		inst->types[i] = NULL;
 	}
 
-#ifdef HAVE_PTHREAD_H
 	pthread_mutex_destroy(&(inst->session_mutex));
-	pthread_mutex_destroy(&(inst->module_mutex));
-#endif
 
 	if (inst->default_eap_type_name) free(inst->default_eap_type_name);
 	free(inst);
@@ -76,6 +69,24 @@ static int eap_detach(void *instance)
 }
 
 
+/*
+ *	Compare two handlers.
+ */
+static int eap_handler_cmp(const void *a, const void *b)
+{
+	const EAP_HANDLER *one = a;
+	const EAP_HANDLER *two = b;
+
+	if (one->eap_id < two->eap_id) return -1;
+	if (one->eap_id > two->eap_id) return +1;
+
+	if (one->src_ipaddr < two->src_ipaddr) return -1;
+	if (one->src_ipaddr > two->src_ipaddr) return +1;
+
+	return memcmp(one->state, two->state, sizeof(one->state));
+}
+
+
 /*
  * read the config section and load all the eap authentication types present.
  */
@@ -172,24 +183,23 @@ static int eap_instantiate(CONF_SECTION *cs, void **instance)
 	/* Generate a state key, specific to eap */
 	generate_key();
 
-#ifdef HAVE_PTHREAD_H
+	/*
+	 *	Lookup sessions in the tree.  We don't free them in
+	 *	the tree, as that's taken care of elsewhere...
+	 */
+	inst->session_tree = rbtree_create(eap_handler_cmp, NULL, 0);
+	if (!inst->session_tree) {
+		radlog(L_ERR|L_CONS, "rlm_eap: Cannot initialize tree");
+		eap_detach(inst);
+		return -1;
+	}
+
 	pthread_mutex_init(&(inst->session_mutex), NULL);
-	pthread_mutex_init(&(inst->module_mutex), NULL);
-#endif
 
 	*instance = inst;
 	return 0;
 }
 
-/*
- *	Dumb wrapper.
- *	FIXME: this should be done more intelligently...
- */
-static void my_handler_free(void *data)
-{
-  EAP_HANDLER *handler = (EAP_HANDLER *) data;
-  eap_handler_free(&handler);
-}
 
 /*
  *	For backwards compatibility.
@@ -200,9 +210,6 @@ static int eap_authenticate(void *instance, REQUEST *request)
 	EAP_HANDLER	*handler;
 	eap_packet_t	*eap_packet;
 	int		rcode;
-#ifdef HAVE_PTHREAD_H
-	int		locked = FALSE;
-#endif
 
 	inst = (rlm_eap_t *) instance;
 
@@ -237,7 +244,7 @@ static int eap_authenticate(void *instance, REQUEST *request)
 		case PW_EAP_PEAP:
 			DEBUG2(" rlm_eap: Unable to tunnel TLS inside of TLS");
 			eap_fail(handler);
-			eap_handler_free(&handler);
+			eap_handler_free(handler);
 			return RLM_MODULE_INVALID;
 			break;
 
@@ -247,39 +254,18 @@ static int eap_authenticate(void *instance, REQUEST *request)
 		}
 	}
 
-#ifdef HAVE_PTHREAD_H
-	else {			/* it's a normal request from a NAS */
-		/*
-		 *	The OpenSSL code isn't strictly thread-safe,
-		 *	as we've got to provide callback functions.
-		 *
-		 *	Rather than doing that, we just ensure that the
-		 *	sub-modules are locked via a mutex.
-		 *
-		 *	Don't lock it if we're calling ourselves recursively,
-		 *	we've already got the lock.
-		 */
-		pthread_mutex_lock(&(inst->module_mutex));
-		locked = TRUE;	/* for recursive calls to the module */
-	}
-#endif
-
 	/*
 	 *	Select the appropriate eap_type or default to the
 	 *	configured one
 	 */
 	rcode = eaptype_select(inst, handler);
 
-#ifdef HAVE_PTHREAD_H
-	if (locked) pthread_mutex_unlock(&(inst->module_mutex));
-#endif
-
 	/*
 	 *	If it failed, die.
 	 */
 	if (rcode == EAP_INVALID) {
 		eap_fail(handler);
-		eap_handler_free(&handler);
+		eap_handler_free(handler);
 		DEBUG2("  rlm_eap: Failed in EAP select");
 		return RLM_MODULE_INVALID;
 	}
@@ -296,7 +282,7 @@ static int eap_authenticate(void *instance, REQUEST *request)
 		 */
 		rcode = request_data_add(request,
 					 inst, REQUEST_DATA_EAP_HANDLER,
-					 handler, my_handler_free);
+					 handler, eap_handler_free);
 		rad_assert(rcode == 0);
 
 		return RLM_MODULE_HANDLED;
@@ -319,7 +305,7 @@ static int eap_authenticate(void *instance, REQUEST *request)
 		 */
 		rcode = request_data_add(request,
 					 inst, REQUEST_DATA_EAP_HANDLER,
-					 handler, my_handler_free);
+					 handler, eap_handler_free);
 		rad_assert(rcode == 0);
 
 		/*
@@ -381,7 +367,7 @@ static int eap_authenticate(void *instance, REQUEST *request)
 	} else {
 		DEBUG2("  rlm_eap: Freeing handler");
 		/* handler is not required any more, free it now */
-		eap_handler_free(&handler);
+		eap_handler_free(handler);
 	}
 
 	/*
@@ -510,7 +496,7 @@ static int eap_post_proxy(void *inst, REQUEST *request)
 							      REQUEST_DATA_EAP_TUNNEL_CALLBACK);
 		if (!data) {
 			radlog(L_ERR, "rlm_eap: Failed to retrieve callback for tunneled session!");
-			eap_handler_free(&handler);
+			eap_handler_free(handler);
 			return RLM_MODULE_FAIL;
 		}
 
@@ -521,7 +507,7 @@ static int eap_post_proxy(void *inst, REQUEST *request)
 		free(data);
 		if (rcode == 0) {
 			eap_fail(handler);
-			eap_handler_free(&handler);
+			eap_handler_free(handler);
 			return RLM_MODULE_REJECT;
 		}
 
@@ -542,7 +528,7 @@ static int eap_post_proxy(void *inst, REQUEST *request)
 		} else {	/* couldn't have been LEAP, there's no tunnel */
 			DEBUG2("  rlm_eap: Freeing handler");
 			/* handler is not required any more, free it now */
-			eap_handler_free(&handler);
+			eap_handler_free(handler);
 		}
 
 		/*
@@ -640,7 +626,7 @@ static int eap_post_proxy(void *inst, REQUEST *request)
 module_t rlm_eap = {
 	"eap",
 	RLM_TYPE_THREAD_SAFE,		/* type */
-	eap_init,			/* initialization */
+	NULL,				/* initialization */
 	eap_instantiate,		/* instantiation */
 	{
 		eap_authenticate,	/* authentication */
