@@ -1,7 +1,7 @@
 /*
  * rlm_radutmp.c
  *
- * Version:	$Id: rlm_radutmp.c,v 1.24 2004/02/26 19:04:34 aland Exp $
+ * Version:	$Id$
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -589,6 +589,7 @@ static int radutmp_checksimul(void *instance, REQUEST *request)
 	rlm_radutmp_t	*inst = instance;
 	char		login[256];
 	char		filename[1024];
+	ssize_t		read_size;
 
 	/*
 	 *	Get the filename, via xlat.
@@ -629,7 +630,7 @@ static int radutmp_checksimul(void *instance, REQUEST *request)
 	/*
 	 *	Loop over utmp, counting how many people MAY be logged in.
 	 */
-	while (read(fd, &u, sizeof(u)) == sizeof(u)) {
+	while ((read_size = read(fd, &u, sizeof(u))) == sizeof(u)) {
 		if (((strncmp(login, u.login, RUT_NAMESIZE) == 0) ||
 		     (!inst->case_sensitive &&
 		      (strncasecmp(login, u.login, RUT_NAMESIZE) == 0))) &&
@@ -638,6 +639,13 @@ static int radutmp_checksimul(void *instance, REQUEST *request)
 		}
 	}
 
+	if (read_size < 0) {
+		radlog(L_ERR, "rlm_radutmp: Error reading %s: %s",
+		       filename, strerror(errno));
+		close(fd);
+		return RLM_MODULE_FAIL;
+	}
+
 	/*
 	 *	The number of users logged in is OK,
 	 *	OR, we've been told to not check the NAS.
@@ -669,7 +677,7 @@ static int radutmp_checksimul(void *instance, REQUEST *request)
 	 *	static IP's like DSL.
 	 */
 	request->simul_count = 0;
-	while (read(fd, &u, sizeof(u)) == sizeof(u)) {
+	while ((read_size = read(fd, &u, sizeof(u))) == sizeof(u)) {
 		if (((strncmp(login, u.login, RUT_NAMESIZE) == 0) ||
 		     (!inst->case_sensitive &&
 		      (strncasecmp(login, u.login, RUT_NAMESIZE) == 0))) &&
@@ -740,6 +748,14 @@ static int radutmp_checksimul(void *instance, REQUEST *request)
 			}
 		}
 	}
+
+	if (read_size < 0) {
+		radlog(L_ERR, "rlm_radutmp: Error reading %s: %s",
+		       filename, strerror(errno));
+		close(fd);
+		return RLM_MODULE_FAIL;
+	}
+
 	close(fd);		/* and implicitely release the locks */
 
 	return RLM_MODULE_OK;
