@@ -1,7 +1,7 @@
 /*
  * rlm_sqlcounter.c
  *
- * Version:  $Id: rlm_sqlcounter.c,v 1.11.2.3.2.6 2006/11/18 14:45:19 nbk Exp $
+ * Version:  $Id$
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -55,7 +55,7 @@
  */
 
 
-static const char rcsid[] = "$Id: rlm_sqlcounter.c,v 1.11.2.3.2.6 2006/11/18 14:45:19 nbk Exp $";
+static const char rcsid[] = "$Id$";
 
 /*
  *	Define a structure for our module configuration.
@@ -305,7 +305,6 @@ static int sqlcounter_expand(char *out, int outlen, const char *fmt, void *insta
 	const char *p;
 	char *q;
 	char tmpdt[40]; /* For temporary storing of dates */
-	int openbraces=0;
 
 	q = out;
 	for (p = fmt; *p ; p++) {
@@ -315,15 +314,6 @@ static int sqlcounter_expand(char *out, int outlen, const char *fmt, void *insta
 			break;
 		c = *p;
 		if ((c != '%') && (c != '$') && (c != '\\')) {
-			/*
-			 * We check if we're inside an open brace.  If we are
-			 * then we assume this brace is NOT literal, but is
-			 * a closing brace and apply it
-			 */
-			if((c == '}') && openbraces) {
-				openbraces--;
-				continue;
-			}
 			*q++ = *p;
 			continue;
 		}
@@ -548,7 +538,7 @@ static int sqlcounter_instantiate(CONF_SECTION *conf, void **instance)
 	dattr = dict_attrbyname(data->check_name);
 	if (dattr == NULL) {
 		radlog(L_ERR, "rlm_sqlcounter: Failed to create check attribute %s",
-				data->counter_name);
+				data->check_name);
 		return -1;
 	}
 	DEBUG2("rlm_sqlcounter: Check attribute %s is number %d",
