@@ -3,7 +3,7 @@
  *		accounting:     Functions to write radwtmp file.
  *		Also contains handler for "Group".
  *
- * Version:	$Id: rlm_unix.c,v 1.63 2004/02/26 19:04:37 aland Exp $
+ * Version:	$Id$
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -23,7 +23,7 @@
  * Copyright 2000  Jeff Carneal <jeff@apex.net>
  * Copyright 2000  Alan Curry <pacman@world.std.com>
  */
-static const char rcsid[] = "$Id: rlm_unix.c,v 1.63 2004/02/26 19:04:37 aland Exp $";
+static const char rcsid[] = "$Id$";
 
 #include	"autoconf.h"
 #include	"libradius.h"
@@ -223,7 +223,7 @@ static int groupcmp(void *instance, REQUEST *req, VALUE_PAIR *request,
 	}
 	username = (char *)vp->strvalue;
 
-	if (group_inst->cache_passwd &&
+	if (group_inst->cache &&
 	    (retval = H_groupcmp(group_inst->cache, check, username)) != -2)
 		return retval;
 
@@ -474,7 +474,7 @@ static int unix_authenticate(void *instance, REQUEST *request)
 	name = (char *)request->username->strvalue;
 	passwd = (char *)request->password->strvalue;
 
-	if (inst->cache_passwd &&
+	if (inst->cache &&
 	    (ret = H_unix_pass(inst->cache, name, passwd, &request->reply->vps)) != -2)
 		return (ret == 0) ? RLM_MODULE_OK : RLM_MODULE_REJECT;
 
